// ---------------------------------------------------------
// FILTER Product
// ---------------------------------------------------------
("use strict");
var Shuffle = window.Shuffle;

var Grid_filter = function Grid_filter(element) {
    this.element = element;
    this.tags_property = document.getElementById("recorder_products");
    this.reset = Array.from(
        document.querySelectorAll(".filter_reset")
    );
    this.genres = Array.from(
        document.querySelectorAll(".filter_genre_item")
    );
    this.shuffle = new Shuffle(element, {
        itemSelector: ".shuffle_item",
    });
    this.filters = {
        genres: [],
    };
    this._bindEventListeners();
    this.filter();

    /*----- IF PARAMETERS EXIST -----*/
    var currentParam = location.search;
    if (currentParam !== "") {
        var paramGenre = this._getUrlParam("genre");

        if (paramGenre.length > 0) {
                jQuery(
                    ".filter_genre_item[data-value='" +
                    paramGenre +
                          "']"
                ).click();
        }
    }
};

/*----- GET PARAM FROM URL -----*/
Grid_filter.prototype._getUrlParam = function (parameter) {
    var urlparameter = [];

    if (window.location.href.indexOf(parameter) > -1) {
    urlparameter.push(this._getUrlVars()[parameter]);
    }

    return decodeURIComponent(urlparameter);
};
Grid_filter.prototype._getUrlVars = function () {
    var vars = {};
    var parts = window.location.href.replace(
    /[?&]+([^=&]+)=([^&]*)/gi,
    function (m, key, value) {
        vars[key] = value;
    }
    );
    return vars;
};

/*----- BIND EVENT FOR FILTER -----*/
Grid_filter.prototype._bindEventListeners = function () {
    this._onResetClick = this._handleResetClick.bind(this);
    this._onGenreClick = this._handleGenreClick.bind(this);
    this.reset.forEach(function (button) {
        button.addEventListener("click", this._onResetClick);
    }, this);
    this.genres.forEach(function (button) {
        button.addEventListener("click", this._onGenreClick);
    }, this);
};

/*----- GET THE ACTIVE BUTTON/FILTER -----*/
//genre active button
Grid_filter.prototype._getCurrentGenreFilters = function () {
    return this.genres
    .filter(function (button) {
        return button.classList.contains("active");
    })
    .map(function (button) {
        return button.getAttribute("data-value");
    });
};

/*----- HANDLE CHANGES/CLICK -----*/
//reset
Grid_filter.prototype._handleResetClick = function (evt) {
    this.filters = {
        genres: [],
    };
    this.filter();
    
    this.genres.forEach(function (btn) {
        btn.classList.remove("active");
    });
    
    this.tags_property.setAttribute("data-gen", "");

    var newurl =
        window.location.protocol +
        "//" +
        window.location.host +
        window.location.pathname;
    window.history.pushState({ path: newurl }, "", newurl);
};

//click on Genre
Grid_filter.prototype._handleGenreClick = function (evt) {
    var button = evt.currentTarget;

    if (button.classList.contains("active")) {
        button.classList.remove("active");
    } else {
        this.genres.forEach(function (btn) {
            btn.classList.remove("active");
        });
        button.classList.add("active");
    }

    this.filters.genres = this._getCurrentGenreFilters();
    this.filter();
    this.tags_property.setAttribute(
        "data-gen",
        this.filters.genres
        );
    this.createParam();
};

/*----- ADD/UPDATE PARAMETERS -----*/
Grid_filter.prototype.createParam = function () {
    var parameters = [];
    var newurl;
    var dataG = this.tags_property.getAttribute("data-gen");

    if (dataG !== "") {
        parameters.push("genre=" + dataG);
    }
    
    if (parameters.length > 0) {
        newurl =
            window.location.protocol +
            "//" +
            window.location.host +
            window.location.pathname +
            "?" +
            parameters.join("&");
        } else {
        newurl =
            window.location.protocol +
            "//" +
            window.location.host +
            window.location.pathname;
        }
    
        window.history.pushState({ path: newurl }, "", newurl);
};


/*----- SHUFFLE BASES ON CURRENT STATEMENT -----*/
Grid_filter.prototype.filter = function () {
    this.shuffle.filter(this.itemPassesFilters.bind(this));

    /*----- Disabled filter value when doen't exist in result -----*/
    var genreFilterBtn = jQuery(
        ".filter_genre_item"
    );
    
    genreFilterBtn.each(function () {
        var genreExist = jQuery(
            "#recorder_products li.shuffle-item--visible[data-genre*='" +
            jQuery(this).attr("data-value") +
            "']"
        );
        if (genreExist.length === 0) {
            jQuery(this).parent().addClass("hidden");
        } else {
            jQuery(this).parent().removeClass("hidden");
        }
    });
};

/*----- PASSED ITEMS ON FILTER -----*/
Grid_filter.prototype.itemPassesFilters = function (element) {
    var genres = this.filters.genres;
    var genre = element.getAttribute("data-genre");

    if (genres.length > 0 && genres.some(v=> genre.indexOf(v) === -1)) {
        return false;
    }
    return true;
};

/*----- APPLY GRID FILTER PROTOTYPE -----*/
document.addEventListener("DOMContentLoaded", function () {
    window.grid_filter = new Grid_filter(
        document.querySelector(".shuffle_container")
    );
});


// ---------------------------------------------------------
// Other JS
// ---------------------------------------------------------

document.addEventListener("DOMContentLoaded", function () {

    /* ----- Tab function ----- */
    var tabBtn = Array.from(
        document.querySelectorAll(".tab_label")
    );
    var tabMain = Array.from(
        document.querySelectorAll(".tab_content")
    );
    var tabContent = Array.from(
        document.querySelectorAll(".tab_content_inner")
    );

    var openTab = function (evt) {
        var tablabel = evt.currentTarget;
        tabBtn.forEach(function (btn) {
            btn.classList.remove("on");
        });
        tablabel.classList.add("on");

        tabMain.forEach(function (content) {
            content.classList.add("off");
        });
        var dataTab = tablabel.getAttribute("data-tab");
        document.getElementById(dataTab).classList.remove("off");

        tabContent.forEach(function (content) {
            content.classList.add("off");
        });
        var dataContent = tablabel.getAttribute("data-content");
        document.getElementById(dataContent).classList.remove("off");
    }
    tabBtn.forEach(function (btn) {
        btn.addEventListener("click", openTab);
    });
    
    /* ----- spec selector ----- */
    var specBtn = Array.from(
        document.querySelectorAll(".tab_spec_btn")
    );
    var specProductCol = Array.from(
        document.querySelectorAll(".spec_table_col")
    );
    var specClear = Array.from(
        document.querySelectorAll("#tab_mr button.clear-filter")
    );
    var tabSizer = Array.from(
        document.querySelectorAll(".spec_table_sizer")
    );

    var smartphone = false;
    var arraySelected = [];
    var arrayAtt01 = ['vp-20'];
    var arrayAtt02 = ['ls-p5','dm-750','ws-883','vp-20'];
    var arrayAtt03 = ['ws-882','vn-551pc'];

    var findCommonElement = function (array1, array2) {
        for (let i = 0; i < array1.length; i++) {
            for (let j = 0; j < array2.length; j++) {
                if (array1[i] === array2[j]) {
                    // Return if common element found
                    return true;
                }
            }
        }
        // Return if no common element exist
        return false;
    }

    window.onload = function() {
        if(window.innerWidth > 500){
            smartphone = false;
        }else{
            smartphone = true;
        }
    };
    window.onresize = function() {
        if(window.innerWidth > 500){
            smartphone = false;
        }else{
            smartphone = true;
        }
    };

    var specResetTable = function (evt){
        specProductCol.forEach(function (col){
            col.classList.remove('off');
        });
        arraySelected = [];
        specBtn.forEach(function (btn){
            btn.classList.remove('active');
        });
        if(!smartphone){
            document.querySelector(".spec_table_btn_prev").style.display = 'block';
            document.querySelector(".spec_table_btn_next").style.display = 'block';
        }
        document.querySelector("#attention01").style.display = 'block';
        document.querySelector("#attention02").style.display = 'block';
        document.querySelector("#attention03").style.display = 'block';
        tabSizer.forEach(function (sizer){
            sizer.setAttribute("colspan", 6);
        });
        specProductCol.forEach(function (col){
            col.style.removeProperty('width');
        });   
    }

    var selectProduct = function (evt) {
        var currentSelect = evt.currentTarget;
        var dataProduct = currentSelect.getAttribute("data-prod");
        var resetStatut = false;

        if(currentSelect.classList.contains("active")){
            currentSelect.classList.remove("active");
            arraySelected = arraySelected.filter(function (el) {
                return el !== dataProduct;
            });
        }else{
            currentSelect.classList.add("active");
            arraySelected.push(dataProduct);
        }

        resetStatut = specBtn.every(function (btn){
            if(btn.classList.contains('active')){
                return false;
            }else{
                return true;
            }
        });

        if(resetStatut === true){
            specResetTable();
        }else{
            specProductCol.forEach(function (col){
                let classes = col.classList;
                if(findCommonElement(classes,arraySelected)){
                    col.classList.remove('off');
                    if(smartphone){
                        if(arraySelected.length === 1){
                            col.style.width = 'calc(100vw - 30px)';
                        }else if(arraySelected.length === 2){
                            col.style.width = 'calc(50vw - 30px)';
                        }else{
                            col.style.removeProperty('width');
                        }
                    }
                }else{
                    col.classList.add('off');
                }
            });
            if(!smartphone){
                if(arraySelected.length > 3){
                    document.querySelector(".spec_table_btn_prev").style.display = 'block';
                    document.querySelector(".spec_table_btn_next").style.display = 'block';
                }else{
                    document.querySelector(".spec_table_btn_prev").style.display = 'none';
                    document.querySelector(".spec_table_btn_next").style.display = 'none';
                }
            }

            if(findCommonElement(arrayAtt01,arraySelected)){
                document.querySelector("#attention01").style.display = 'block';
            }else{
                document.querySelector("#attention01").style.display = 'none';
            }

            if(findCommonElement(arrayAtt02,arraySelected)){
                document.querySelector("#attention02").style.display = 'block';
            }else{
                document.querySelector("#attention02").style.display = 'none';
            }

            if(findCommonElement(arrayAtt03,arraySelected)){
                document.querySelector("#attention03").style.display = 'block';
            }else{
                document.querySelector("#attention03").style.display = 'none';
            }

            if(smartphone){
                tabSizer.forEach(function (sizer){
                    sizer.setAttribute("colspan", arraySelected.length - 1 );
                });
            }else{
                tabSizer.forEach(function (sizer){
                    sizer.setAttribute("colspan", arraySelected.length);
                });
            }

        }
        
    }

    specBtn.forEach(function (button) {
        button.addEventListener("click", selectProduct);
    });
    specClear.forEach(function(button){
        button.addEventListener("click", specResetTable);
    });

    /* ----- PREV/NEXT button ----- */
    const rightBtn = document.querySelector('.spec_table_btn_next');
    const leftBtn = document.querySelector('.spec_table_btn_prev');
    let slideW = jQuery("th.spec_table_col").eq(0).outerWidth();

    rightBtn.addEventListener("click", function(event) {
    const table = document.querySelector('.spec_table_wrapper');
    table.scrollLeft += slideW;
    event.preventDefault();
    });

    leftBtn.addEventListener("click", function(event) {
    const table = document.querySelector('.spec_table_wrapper');
    table.scrollLeft -= slideW;
    event.preventDefault();
    });

    /* ----- drag and scroll ----- */
    const slider = document.querySelector('.spec_table_wrapper');
    let isDown = false;
    let startX;
    let scrollLeft;

    slider.addEventListener('mousedown', (e) => {
    isDown = true;
    slider.classList.add('active');
    startX = e.pageX - slider.offsetLeft;
    scrollLeft = slider.scrollLeft;
    });

    slider.addEventListener('mouseleave', () => {
    isDown = false;
    slider.classList.remove('active');
    });

    slider.addEventListener('mouseup', () => {
    isDown = false;
    slider.classList.remove('active');
    });

    slider.addEventListener('mousemove', (e) => {
    if(!isDown) return;
    e.preventDefault();
    const x = e.pageX - slider.offsetLeft;
    const walk = (x - startX) * 3; //scroll-fast
    slider.scrollLeft = scrollLeft - walk;
    console.log(walk);
    });

});  